@@ -14,7 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# $Id: dio.tcl 610070 2008-01-08 17:10:41Z mxmanghi $
+# $Id: dio.tcl 1339855 2012-05-17 20:41:38Z mxmanghi $
 
 catch {package require Tclx}
 package require Itcl
@@ -241,7 +241,7 @@ proc handle {interface args} {
 	# multiple fields, construct it as a where-and
 	set req " WHERE 1 = 1"
 	foreach field $myKeyfield key $myKey {
-	    append req " AND $field=[makeDBFieldValue $table $field $key]"
+	    append req " AND $field = [makeDBFieldValue $table $field $key]"
 	}
 	return $req
     }
@@ -547,7 +547,7 @@ proc handle {interface args} {
     #
     method delete {key args} {
 	table_check $args
-	set req "delete from $myTable"
+	set req "DELETE FROM $myTable"
 	append req [build_key_where_clause $myKeyfield $key]
 
 	set res [exec $req]
